@@ -1,7 +1,7 @@
 package OpenGuides::CGI;
 use strict;
 use vars qw( $VERSION );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use Carp qw( croak );
 use CGI::Cookie;
@@ -30,7 +30,9 @@ This documentation is probably only useful to OpenGuides developers.
       username               => "Kake",
       include_geocache_link  => 1,
       preview_above_edit_box => 1,
-      latlong_traditional    => 1
+      latlong_traditional    => 1,
+      omit_formatting_link   => 1,
+      show_minor_edits_in_rc => 1,
   );
 
   my $wiki = OpenGuides::Utils->make_wiki_object( config => $config );
@@ -56,7 +58,9 @@ This documentation is probably only useful to OpenGuides developers.
       username               => "Kake",
       include_geocache_link  => 1,
       preview_above_edit_box => 1,
-      latlong_traditional    => 1
+      latlong_traditional    => 1,
+      omit_formatting_link   => 1,
+      show_minor_edits_in_rc => 1,
   );
 
 Croaks unless a L<Config::Tiny> object is supplied as C<config>.
@@ -71,10 +75,14 @@ sub make_prefs_cookie {
     my $cookie_name = $class->_get_cookie_name( config => $config );
     my $cookie = CGI::Cookie->new(
         -name  => $cookie_name,
-	-value => { user   => $args{username},
-		    gclink => $args{include_geocache_link},
-                    prevab => $args{preview_above_edit_box},
-                    lltrad => $args{latlong_traditional} }
+	-value => { user      => $args{username},
+		    gclink    => $args{include_geocache_link},
+                    prevab    => $args{preview_above_edit_box},
+                    lltrad    => $args{latlong_traditional},
+                    omitfmtlk => $args{omit_formatting_link},
+                    rcmined   => $args{show_minor_edits_in_rc},
+                  },
+        -expires => "+1M",
     );
     return $cookie;
 }
@@ -101,10 +109,13 @@ sub get_prefs_from_cookie {
     if ( $cookies{$cookie_name} ) {
         %data = $cookies{$cookie_name}->value; # call ->value in list context
     }
-    return ( username               => $data{user} || "Anonymous",
-             include_geocache_link  => $data{gclink} || 0,
-             preview_above_edit_box => $data{prevab} || 0,
-             latlong_traditional    => $data{lltrad} || 0  );
+    return ( username               => $data{user}      || "Anonymous",
+             include_geocache_link  => $data{gclink}    || 0,
+             preview_above_edit_box => $data{prevab}    || 0,
+             latlong_traditional    => $data{lltrad}    || 0,
+             omit_formatting_link   => $data{omitfmtlk} || 0,
+             show_minor_edits_in_rc => $data{rcmined}   || 0,
+           );
 }
 
 sub _get_cookie_name {
